@@ -19,7 +19,7 @@ class Frame(DeeplabelBase):
     resolution:FrameResolution
     video_id: str
     frame_id: str
-    frame_url:str
+    frame_url:Optional[str]
     point_in_time:float
     detections:List[detections.Detection]
     assignee:Optional[str]
